// AppController -- Application controller for ThumbBorker

// Copyright (C) 2005 Borkware, LLC
// We use the BSD License.  Check out http://borkware.com/license

#import <Cocoa/Cocoa.h>

@class BWSearchArrayController;
@class BWSelectableImageView;
@class BWFileList;
@class BWSnippetKeeper;

@interface AppController : NSObject
{
    // the list of image files that have been found in the directory
    // specified by the user
    BWFileList *fileList;

    // the images the user wants to make thumbnails out of.
    // holds a sequence of BWFileEntrys
    NSMutableArray *chosenImages;

    // IB doesn't let us set up bindings from array controllers to
    // objects other than "File's Owner" or the shared prefs controller,
    // so some of the bindings will be made manually with these
    // controllers
    IBOutlet BWSearchArrayController *imagesController;
    IBOutlet NSArrayController *chosenImagesController;

    IBOutlet NSWindow *mainWindow;

    // the text field at the bottom of the window that shows the
    // path of the imagbe being displayed
    IBOutlet NSTextField *statusField;

    // displays the image and lets the user drag out a selection rectangle.
    // Only interaction with this is via bindings
    IBOutlet BWSelectableImageView *imageView;

    // the rotate button
    IBOutlet NSButton *rotateCCWButton;
    IBOutlet NSButton *rotateCWButton;

    // just used to compare against in responder change notification.
    // The bindings to the status field and the imageView are changed
    // when the tableviews change focus
    IBOutlet NSTableView *originalFilesTableview;
    IBOutlet NSTableView *thumbnailsTableview;

    // holds the chunklets of HTML that are used to generate the optional
    // HTML page that contains the images
    BWSnippetKeeper *snippets;

    // keep track of the controller that is controlling the
    // status line and imageView.  Don't unbind and rebind if
    // window focus games keep the same tableview in focus.
    NSArrayController *lastBoundController;
}

// menu item.  Present a sheet to choose a directory, which gets walked
// looking for images
- (IBAction) loadDirectory: (id) sender;

// move the image into the "make thumbnails out of me" list
- (IBAction) keep: (id) sender;

// generate the thumbnails, prompting the user for a destination first
- (IBAction) makeThumbnails: (id) sender;

// show a sheet where the user can enter the various HTML chunklets
- (IBAction) showHTMLSnippets: (id) sender;

// rotate the image in 90 degree increments.  tag indicates whether
// clockwise (-1) or counter-clockwise (1)
- (IBAction) rotate: (id) sender;

@end // AppController

